#!/usr/bin/env python
# -*- coding: utf-8 -*-

import io
import os
import sys
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = "mewtools"
DESCRIPTION = "My python library package with some scraper tool and data tool"
URL = "https://github.com/sizzlingbun/mewtools"
EMAIL = "me@example.com"
AUTHOR = "Andrew"
REQUIRES_PYTHON = ">=3.10.0"
VERSION = "0.1.4"

# What packages are required for this module to be executed?
REQUIRED = [
    "addict==2.4.0",
    "carehttp>=0.3.11",
    "certifi==2022.5.18.1",
    "charset-normalizer==2.0.12",
    "colorama==0.4.4",
    "date-extractor==5.1.5",
    "dateparser==1.1.1",
    "filetype==1.0.13",
    "humanize==4.1.0",
    "idna>=2.8",
    "loguru==0.6.0",
    "maya==0.6.1",
    "pendulum==2.1.2",
    "python-dateutil==2.8.2",
    "pytz==2022.1",
    "pytz-deprecation-shim==0.1.0.post0",
    "pytzdata==2020.1",
    "regex==2022.3.2",
    "requests>=2.22.0",
    "requests-toolbelt==0.9.1",
    "retrying==1.3.3",
    "six==1.16.0",
    "snaptime==0.2.4",
    "tzdata",
    "tzlocal==4.2",
    "urllib3>=1.25.11",
    "win32-setctime==1.1.0",
    "arrow~=1.2.2",
]

# What packages are optional?
EXTRAS = {
    # 'fancy feature': ['django'],
}

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
try:
    with io.open(os.path.join(here, "README.md"), encoding="utf-8") as f:
        long_description = "\n" + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    project_slug = NAME.lower().replace("-", "_").replace(" ", "_")
    with open(os.path.join(here, project_slug, "__version__.py")) as f:
        exec(f.read(), about)
else:
    about["__version__"] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print("\033[1m{0}\033[0m".format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status("Removing previous builds…")
            rmtree(os.path.join(here, "dist"))
        except OSError:
            pass

        self.status("Building Source and Wheel (universal) distribution…")
        os.system("{0} setup.py sdist bdist_wheel --universal".format(sys.executable))

        self.status("Uploading the package to PyPI via Twine…")
        os.system("twine upload dist/*")

        self.status("Pushing git tags…")
        os.system("git tag v{0}".format(about["__version__"]))
        os.system("git push --tags")

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about["__version__"],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=["tests", "*.tests", "*.tests.*", "tests.*"]),
    # If your package is a single module, use this instead of 'packages':
    py_modules=["mewtools"],
    # entry_points={
    #     'console_scripts': ['mycli=mymodule:cli'],
    # },
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license="MIT",
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    # $ setup.py publish support.
    cmdclass={
        "upload": UploadCommand,
    },
)
